@@ -142,6 +142,8 @@ EXTERN void nfs_destroy_context(struct nfs_context *nfs);
  *                     default it 65534 on Windows and getuid() on unixen.
  * gid=<int>         : GID value to use when talking to the server.
  *                     default it 65534 on Windows and getgid() on unixen.
+ * readahead=<int>   : Enable readahead for files and set the maximum amount
+ *                     of readahead to <int>.
  */
 /*
  * Parse a complete NFS URL including, server, path and
@@ -384,7 +386,14 @@ EXTERN int nfs_fstat64_async(struct nfs_context *nfs, struct nfsfh *nfsfh, nfs_c
  */
 EXTERN int nfs_fstat64(struct nfs_context *nfs, struct nfsfh *nfsfh, struct nfs_stat_64 *st);
 
-
+/*
+ * UMASK() never blocks, so no special aync/async versions are available
+ */
+/*
+ * Sync umask(<mask>)
+ * Function returns the old mask.
+ */
+EXTERN uint16_t nfs_umask(struct nfs_context *nfs, uint16_t mask);
 
 /*
  * OPEN()
@@ -1411,13 +1420,6 @@ EXTERN struct exportnode *mount_getexports(const char *server);
 EXTERN void mount_free_export_list(struct exportnode *exports);
 
 
-//qqq replace later with lseek(cur, 0)
-uint64_t nfs_get_current_offset(struct nfsfh *nfsfh);
-
-
-
-
-
 struct nfs_server_list {
        struct nfs_server_list *next;
        char *addr;
